/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: greportwidget.cpp 358 2006-01-16 23:08:37Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include "greportwidget.h"
#include <qpixmap.h>




GraphicReportWidget::GraphicReportWidget(RefPointer<QPixmap> pm,
                                         QWidget *parent,
                                         const char *name,
                                         WFlags f)
:QWidget(parent, name, f), _pixMap(pm) {

}



GraphicReportWidget::~GraphicReportWidget() {
}



void GraphicReportWidget::paintEvent(QPaintEvent*) {
  QPainter p(this);

  DBG_ERROR(0, "Drawing...");
  if (_pixMap.isValid())
    p.drawPixmap(0, 0, _pixMap.ref());
}







